@@ -14,12 +14,12 @@ class KeenApi(object):
     # the default version of the Keen API
     api_version = "3.0"
 
-    def __init__(self, project_id, auth_token, base_url=None,
+    def __init__(self, project_id, api_key, base_url=None,
                  api_version=None):
         """ Initializes a KeenApi object
 
         :param project_id: the Keen project ID
-        :param auth_token: the Keen authorization token
+        :param api_key: the Keen API key
         :param base_url: optional, set this to override where API requests
         are sent
         :param api_version: string, optional, set this to override what API
@@ -27,7 +27,7 @@ class KeenApi(object):
         """
         super(KeenApi, self).__init__()
         self.project_id = project_id
-        self.auth_token = auth_token
+        self.api_key = api_key
         if base_url:
             self.base_url = base_url
         if api_version:
@@ -41,7 +41,7 @@ class KeenApi(object):
         url = "{}/{}/projects/{}/events/{}".format(self.base_url, self.api_version,
                                             self.project_id,
                                             event.collection_name)
-        headers = {"Authorization": self.auth_token,
+        headers = {"Authorization": self.api_key,
                    "Content-Type": "application/json"}
         payload = event.to_json()
         response = requests.post(url, data=payload, headers=headers)
